@@ -14,6 +14,7 @@ use IPC::Cmd qw(run);
 use File::Copy "cp";
 use Sys::Syslog;
 use JSON;
+use Time::Piece;
 
 =head1 NAME
 
@@ -21,11 +22,11 @@ Virani - PCAP retrieval for a FPC setup writing to PCAP files.
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.3.0
 
 =cut
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
 =head1 SYNOPSIS
 
@@ -166,8 +167,10 @@ sub new {
 	}
 
 	# real in basic values
-	my @real_in
-		= ( 'apikey', 'default_set', 'cache', 'default_max_time', 'verbose_to_syslog', 'verbose', 'auth_by_IP_only' );
+	my @real_in = (
+		'apikey',           'default_set',       'cache',   'padding',
+		'default_max_time', 'verbose_to_syslog', 'verbose', 'auth_by_IP_only'
+	);
 	for my $key (@real_in) {
 		if ( defined( $opts{$key} ) ) {
 			$self->{$key} = $opts{$key};
@@ -528,11 +531,26 @@ The return is a hash reference that includes the following keys.
 
     - using_cache :: If the cache was used or not.
 
+    - req_start :: Timestamp of when the it started. In the format
+                   %Y-%m-%dT%H:%M:%S%z
+
+    - req_start_s :: Same as req_start, but unixtime.
+
+    - req_end :: Timestamp of when the it finished. In the format
+                 %Y-%m-%dT%H:%M:%S%z
+
+    - req_end_s :: Same as req_end, but unixtime.
+
+    - req_time :: Number of seconds it took.
+
 =cut
 
 sub get_pcap_local {
 	my ( $self, %opts ) = @_;
 
+	# start of the request
+	my $req_start = localtime;
+
 	# make sure we have something for type and check to make sure it is sane
 	if ( !defined( $opts{type} ) ) {
 		$opts{type} = $self->{type};
@@ -556,7 +574,7 @@ sub get_pcap_local {
 		die('$opts{start} is not a Time::Piece object');
 	} elsif ( ref( $opts{end} ) ne 'Time::Piece' ) {
 		die('$opts{end} is not a Time::Piece object');
-	} elsif ( defined( $opts{padding} ) && $opts{padding} !~ /^\d+/ ) {
+	} elsif ( defined( $opts{padding} ) && $opts{padding} !~ /^\d+$/ ) {
 		die('$opts{padding} is not numeric');
 	}
 	$self->verbose( 'info', 'Start: ' . $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z') . ', ' . $opts{start}->epoch );
@@ -680,7 +698,8 @@ sub get_pcap_local {
 		regex => $ts_regexp,
 	);
 
-	# The path to return.
+	# The return hash and what will be used for the cache JSON
+	# req_end stuff set later
 	my $to_return = {
 		pcaps         => $to_check,
 		pcap_count    => 0,
@@ -698,8 +717,10 @@ sub get_pcap_local {
 		padding       => $opts{padding},
 		start_s       => $opts{start}->epoch,
 		start         => $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z'),
-		end_s         => => $opts{end}->epoch,
+		end_s         => $opts{end}->epoch,
 		end           => $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z'),
+		req_start     => $req_start->strftime('%Y-%m-%dT%H:%M:%S%z'),
+		req_start_s   => $req_start->epoch,
 	};
 
 	# used for tracking the files to cleanup
@@ -802,6 +823,12 @@ sub get_pcap_local {
 			. " final_size="
 			. $to_return->{final_size} );
 
+	# finalize info on how long the request took
+	my $req_end = localtime;
+	$to_return->{req_end}   = $req_end->strftime('%Y-%m-%dT%H:%M:%S%z');
+	$to_return->{req_end_s} = $req_end->epoch;
+	$to_return->{req_time}  = $req_end->epoch - $req_start->epoch;
+
 	$self->verbose( 'info', 'Creating metadata JSON at "' . $cache_file . '.json" ' );
 	my $json     = JSON->new->allow_nonref->pretty->canonical(1);
 	my $raw_json = $json->encode($to_return);
